==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/EncryptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.EncryptionArgs.builder
import com.pulumi.azurenative.avs.kotlin.enums.EncryptionState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties of customer managed encryption key
 * @property keyVaultProperties The key vault where the encryption key is stored
 * @property status Status of customer managed encryption key
 */
public data class EncryptionArgs(
    public val keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null,
    public val status: Output<Either<String, EncryptionState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.EncryptionArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.EncryptionArgs =
        com.pulumi.azurenative.avs.inputs.EncryptionArgs.builder()
            .keyVaultProperties(
                keyVaultProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EncryptionArgs].
 */
@PulumiTagMarker
public class EncryptionArgsBuilder internal constructor() {
    private var keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null

    private var status: Output<Either<String, EncryptionState>>? = null

    /**
     * @param value The key vault where the encryption key is stored
     */
    @JvmName("subrrjnunkkffpsk")
    public suspend fun keyVaultProperties(`value`: Output<EncryptionKeyVaultPropertiesArgs>) {
        this.keyVaultProperties = value
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("yeiirvbsbxyvctku")
    public suspend fun status(`value`: Output<Either<String, EncryptionState>>) {
        this.status = value
    }

    /**
     * @param value The key vault where the encryption key is stored
     */
    @JvmName("yodvpndutydteypk")
    public suspend fun keyVaultProperties(`value`: EncryptionKeyVaultPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultProperties = mapped
    }

    /**
     * @param argument The key vault where the encryption key is stored
     */
    @JvmName("crtxgjbbauqyvppg")
    public suspend
    fun keyVaultProperties(argument: suspend EncryptionKeyVaultPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionKeyVaultPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVaultProperties = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("urmxjkrwhyuflkom")
    public suspend fun status(`value`: Either<String, EncryptionState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("gtnlksnmdduynhae")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("cjntlhlexhnxpjil")
    public fun status(`value`: EncryptionState) {
        val toBeMapped = Either.ofRight<String, EncryptionState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): EncryptionArgs = EncryptionArgs(
        keyVaultProperties = keyVaultProperties,
        status = status,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/avs/kotlin/inputs/EncryptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.avs.kotlin.inputs

import com.pulumi.azurenative.avs.inputs.EncryptionArgs.builder
import com.pulumi.azurenative.avs.kotlin.enums.EncryptionState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The properties of customer managed encryption key
 * @property keyVaultProperties The key vault where the encryption key is stored
 * @property status Status of customer managed encryption key
 */
public data class EncryptionArgs(
    public val keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null,
    public val status: Output<Either<String, EncryptionState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.avs.inputs.EncryptionArgs> {
    override fun toJava(): com.pulumi.azurenative.avs.inputs.EncryptionArgs =
        com.pulumi.azurenative.avs.inputs.EncryptionArgs.builder()
            .keyVaultProperties(
                keyVaultProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [EncryptionArgs].
 */
@PulumiTagMarker
public class EncryptionArgsBuilder internal constructor() {
    private var keyVaultProperties: Output<EncryptionKeyVaultPropertiesArgs>? = null

    private var status: Output<Either<String, EncryptionState>>? = null

    /**
     * @param value The key vault where the encryption key is stored
     */
    @JvmName("wofaaiytmovtokam")
    public suspend fun keyVaultProperties(`value`: Output<EncryptionKeyVaultPropertiesArgs>) {
        this.keyVaultProperties = value
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("fhpugiqsianpqvye")
    public suspend fun status(`value`: Output<Either<String, EncryptionState>>) {
        this.status = value
    }

    /**
     * @param value The key vault where the encryption key is stored
     */
    @JvmName("tspfkicpsjsrbmfh")
    public suspend fun keyVaultProperties(`value`: EncryptionKeyVaultPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyVaultProperties = mapped
    }

    /**
     * @param argument The key vault where the encryption key is stored
     */
    @JvmName("pirmvapvoriwafhp")
    public suspend
    fun keyVaultProperties(argument: suspend EncryptionKeyVaultPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionKeyVaultPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.keyVaultProperties = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("onifxxoxnvuvvphq")
    public suspend fun status(`value`: Either<String, EncryptionState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("oeblhkmhaavukhdb")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, EncryptionState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Status of customer managed encryption key
     */
    @JvmName("iuhdffbegyajexrw")
    public fun status(`value`: EncryptionState) {
        val toBeMapped = Either.ofRight<String, EncryptionState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): EncryptionArgs = EncryptionArgs(
        keyVaultProperties = keyVaultProperties,
        status = status,
    )
}
